EntryResult

Struct EntryResult 

pub struct EntryResult {
    pub entry_index: Index,
    pub source_info: SourceInfo,
    pub calls: Vec<Call>,
    pub captures: Vec<CaptureResult>,
    pub asserts: Vec<AssertResult>,
    pub errors: Vec<RunnerError>,
    pub transfer_duration: Duration,
    pub compressed: bool,
    pub curl_cmd: CurlCmd,
}
Represents the execution result of an entry.

Fields

entry_index: Index

Index of the entry on the file execution.

source_info: SourceInfo

Source information of this entry.

calls: Vec<Call>

List of HTTP request / response pair.

captures: Vec<CaptureResult>

List of captures.

asserts: Vec<AssertResult>

List of asserts.

errors: Vec<RunnerError>

List of errors.

transfer_duration: Duration

Effective duration of all the HTTP transfers, excluding asserts and captures processing.

compressed: bool

The entry has been executed with --compressed option: server is requested to send compressed response, and the response should be uncompressed when outputted on stdout.

curl_cmd: CurlCmd

The debug curl command line from this entry result.

Implementations

Source

impl EntryResult

pub fn write_response( &self, output: &Output, context_dir: &ContextDir, stdout: &mut Stdout, source_info: SourceInfo, ) -> Result<(), RunnerError>

Writes the last HTTP response of this entry result to this output. The HTTP response can be decompressed if the entry’s compressed option has been set. This method checks if the response has write access to this output, given a context_dir.